@@ -47,6 +47,7 @@ static gchar *hour_url = NULL;
 static gboolean second_attempt = FALSE;
 static CURL *curl_handle = NULL;
 static CURL *curl_handle_hour = NULL;
+static CURL *curl_handle_data = NULL;
 static CURL *curl_multi = NULL;
 static struct curl_slist *headers=NULL;
 static struct HtmlFile html_file, html_file_hour;
@@ -243,11 +244,11 @@ free_curl(void){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-
     curl_slist_free_all(headers);
     headers = NULL;
     curl_multi = NULL;
     curl_handle_hour = NULL;
+    curl_handle_data = NULL;
     curl_handle = NULL;
     app->flag_updating = 0;
 }
@@ -282,7 +283,6 @@ download_html(gpointer data){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-fprintf(stderr, "\nHTML %d\n", max);
     if(app->popup_window && app->show_update_window){
         if(app->config->mode == SIMPLE_MODE)
             destroy_popup_window(GINT_TO_POINTER(1));
@@ -355,14 +355,14 @@ fprintf(stderr, "\nHTML %d\n", max);
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>>>>>>>First stage\n");
 #endif
-        if(app->show_update_window)
-            update_window = create_window_update();     /* Window with update information */
         /* get first station */
         if(!get_station_url
                 (&url, &html_file, &hour_url, &html_file_hour, TRUE)){
             app->flag_updating = 0;
             return FALSE;       /* The strange error */
         }
+        if(app->show_update_window)
+            update_window = create_window_update();     /* Window with update information */
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>Url - %s, File - %s\n", url,
                 html_file.filename);
@@ -569,51 +569,69 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
             gtk_tree_model_iter_next(GTK_TREE_MODEL
                                      (app->user_stations_list), &iter);
     if (valid) {
-        gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
-                           &iter,
-                           ID0_COLUMN, &station_code,
-                           3, &station_source,
-                           -1);
-    if(station_source){
-        /* prepare forecast url */
-        if(get_source_forecast_url(app->sources_list, station_source)){
-            *buffer = 0;
-            snprintf(buffer, sizeof(buffer) - 1,
-                        get_source_forecast_url(app->sources_list, station_source),
-                        station_code);
-            *url = g_strdup(buffer);
-        }
-        /* prepare detail url */
-        if(get_source_detail_url(app->sources_list, station_source)){
-            *buffer = 0;
-            snprintf(buffer, sizeof(buffer) - 1,
-                        get_source_detail_url(app->sources_list, station_source),
-                        station_code);
-            *hour_url = g_strdup(buffer);
+         gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
+                               &iter,
+                               ID0_COLUMN, &station_code,
+                               3, &station_source,
+                               -1);
+        /* Skip Empty  station */
+        while (1){
+            if (station_code && (!strcmp(station_code," ") || !strcmp(station_code,_("Unknown"))) ){
+                valid = gtk_tree_model_iter_next(GTK_TREE_MODEL
+                                         (app->user_stations_list), &iter);
+                if (valid) {
+                    gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
+                               &iter,
+                               ID0_COLUMN, &station_code,
+                               3, &station_source,
+                               -1);
+                }else
+                    break;
+            }else
+                break;
         }
     }
-#ifndef RELEASE
-        fprintf(stderr, "\n>>>>>>>>>>URL %s\n", *url);
-#endif
-        /* preapare filename */
-        memset(buffer, 0, sizeof(buffer));
-        snprintf(buffer, sizeof(buffer) - 1,
-                 "%s/%s.xml.new", app->config->cache_dir_name,
-                 station_code);
-        html_file->filename = g_strdup(buffer);
-        html_file->stream = NULL;
-        memset(buffer, 0, sizeof(buffer));
-        snprintf(buffer, sizeof(buffer) - 1,
-                 "%s/%s_hour.xml.new",
-                 app->config->cache_dir_name, station_code);
-        html_file_hour->filename = g_strdup(buffer);
-        html_file_hour->stream = NULL;
+    if (valid) {
+        if(station_source){
+            /* prepare forecast url */
+            if(get_source_forecast_url(app->sources_list, station_source)){
+                *buffer = 0;
+                snprintf(buffer, sizeof(buffer) - 1,
+                            get_source_forecast_url(app->sources_list, station_source),
+                            station_code);
+                *url = g_strdup(buffer);
+            }
+            /* prepare detail url */
+            if(get_source_detail_url(app->sources_list, station_source)){
+                *buffer = 0;
+                snprintf(buffer, sizeof(buffer) - 1,
+                            get_source_detail_url(app->sources_list, station_source),
+                            station_code);
+                *hour_url = g_strdup(buffer);
+            }
+        }
+    #ifndef RELEASE
+            fprintf(stderr, "\n>>>>>>>>>>URL %s\n", *url);
+    #endif
+            /* preapare filename */
+            memset(buffer, 0, sizeof(buffer));
+            snprintf(buffer, sizeof(buffer) - 1,
+                     "%s/%s.xml.new", app->config->cache_dir_name,
+                     station_code);
+            html_file->filename = g_strdup(buffer);
+            html_file->stream = NULL;
+            memset(buffer, 0, sizeof(buffer));
+            snprintf(buffer, sizeof(buffer) - 1,
+                     "%s/%s_hour.xml.new",
+                     app->config->cache_dir_name, station_code);
+            html_file_hour->filename = g_strdup(buffer);
+            html_file_hour->stream = NULL;
 
-#ifndef RELEASE
-        fprintf(stderr, "\n>>>>>>>>>NAME %s\n", html_file->filename);
-#endif
-        g_free(station_code);
-        g_free(station_source);
+    #ifndef RELEASE
+            fprintf(stderr, "\n>>>>>>>>>NAME %s\n", html_file->filename);
+    #endif
+            g_free(station_code);
+            g_free(station_source);
     }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -666,4 +684,125 @@ check_current_connection(void)
     }
 }
 /*******************************************************************************/
+gboolean
+get_data_from_url(const gchar *data_url, const gchar *path){
+ 
+    CURLMsg *msg = NULL;
+    CURLMcode mret;
+    fd_set rs, ws, es;
+    int max;
+    gint num_transfers = 0, num_msgs = 0;
+    gchar full_filename[2048] ;
+//#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+//#endif
+    *full_filename = 0;
+    snprintf(full_filename, sizeof(full_filename) - 1,"%s/%s.xml",
+                                                          app->config->cache_dir_name, path);
+    if(app->iap_connected){
+         second_attempt = TRUE;
+         fprintf(stderr, "iap_connected");
+    }
+
+    if((!second_attempt) && (!app->iap_connecting)){
+        app->iap_connecting = TRUE;
+#ifdef USE_CONIC
+        if(app->connection)
+            con_ic_connection_connect(app->connection, CON_IC_CONNECT_FLAG_NONE);
+        else
+            return FALSE;
+#else
+    #ifndef NONMAEMO
+        if(osso_iap_connect(OSSO_IAP_ANY, OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK){
+             fprintf(stderr, "after 1 osso_iap_connect(OSSO_IAP_ANY,
+                                             OSSO_IAP_REQUESTED_CONNECT, NULL) != OSSO_OK)\n");
+        }
+     #endif
+#endif
+        fprintf(stderr, "\nbalaaaa\n");
+        second_attempt = TRUE;
+        return TRUE;
+   
+    }
+    fprintf(stderr, "\nbalaaaa\n");
+    
+    if(app->iap_connecting){
+        if(app->iap_connecting_timer > 150){
+           app->iap_connecting = FALSE;
+           fprintf(stderr, "\nCONNECTING %s\n", path);
+           return FALSE;
+        }
+        else{
+            app->iap_connecting_timer++;
+            return TRUE;
+       }
+    }
+
+    second_attempt = FALSE;
+
+    if(app->iap_connected)//{
+        fprintf(stderr, "\nCONNECTED %s\n", path);
+     //   return TRUE;
+  //  }
+//    else
+  //      return FALSE;
+/*
+    if(!curl_handle_data){
+        if(!url)
+           return FALSE;
+        curl_handle_data = weather_curl_init(curl_handle_data);
+        curl_easy_setopt(curl_handle_data, CURLOPT_URL, url);
+        if(!curl_multi)
+           curl_multi = curl_multi_init();
+        max = 0;
+        FD_ZERO(&rs);
+        FD_ZERO(&ws);
+        FD_ZERO(&es);
+        mret = curl_multi_fdset(curl_multi, &rs, &ws, &es, &max);
+        if(mret != CURLM_OK)
+           fprintf(stderr, "Error CURL\n");
+     
+        curl_easy_setopt(curl_handle_data, CURLOPT_WRITEDATA, &full_filename);
+        curl_easy_setopt(curl_handle_data, CURLOPT_WRITEFUNCTION, data_read);
+     
+        curl_multi_add_handle(curl_multi, curl_handle_data);
+        return TRUE;
+    }
+
+    else{
+        num_msgs = 0;
+        while(curl_multi
+                  && (msg = curl_multi_info_read(curl_multi, &num_msgs))) {
+           if(msg->msg == CURLMSG_DONE){
+                if(msg->easy_handle == curl_handle){
+                     mret = curl_multi_remove_handle(curl_multi, curl_handle);
+                     if(mret != CURLM_OK)
+                        fprintf(stderr, " Error remove handle %p\n", curl_handle);
+                      curl_easy_cleanup(curl_handle);
+                      curl_handle = NULL;
+                      if(url){
+                          g_free(url);
+                          url = NULL;
+                       }
+                }
+                if(msg->data.result == CURLE_OK)
+                   if(curl_handle_data)
+                      return TRUE;
+                curl_multi_cleanup(curl_multi);
+                free_curl();
+                return FALSE;
+           }
+        }
+        
+        if(!curl_multi){
+            free_curl();
+            return FALSE;
+        }
+        return TRUE;
+    }
+*/        
+//#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+//#endif
+}
 /*******************************************************************************/
