@@ -33,8 +33,6 @@
 #include "weather-popup.h"
 #include "weather-data.h"
 /*******************************************************************************/
-
-
 gboolean
 jump_panarea(gpointer user_data){
 #ifdef DEBUGFUNCTIONCALL
@@ -45,6 +43,30 @@ jump_panarea(gpointer user_data){
 #endif
     return FALSE;
 }
+GtkWidget*
+create_mainbox_for_forecast_window(GtkWidget* window, gpointer user_data){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+    GtkWidget       *view = NULL,
+                    *main_vbox = NULL;
+    main_vbox = gtk_vbox_new(FALSE, 0);
+    g_object_set_data(G_OBJECT(window), "main_vbox", (gpointer)main_vbox);
+    g_object_set_data(G_OBJECT(window), "user_data", (gpointer)user_data);
+    gtk_box_pack_start(GTK_BOX(main_vbox), create_top_buttons_box(window, user_data), FALSE, TRUE, 0);
+    if (app->config->view_mode == COLLAPSED_VIEW_MODE)
+        gtk_box_pack_start(GTK_BOX(main_vbox), view = create_weather_collapsed_view(main_vbox, (gint)user_data), TRUE, TRUE, 0);
+    else
+        gtk_box_pack_start(GTK_BOX(main_vbox), view = create_weather_expanded_view(main_vbox, (gint)user_data), TRUE, TRUE, 0);
+
+    g_timeout_add(100, (GtkFunction) jump_panarea, view);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
+    return main_vbox;
+}
 
 
 void
@@ -52,6 +74,7 @@ weather_simple_window_popup(GtkWidget *widget, gpointer user_data){
     GtkWidget       *window = NULL,
                     *view = NULL,
                     *main_vbox = NULL;
+//    gboolean        temp = FALSE;
 #if defined OS2009
     HildonAppMenu   *menu = NULL;
 #endif
@@ -64,17 +87,20 @@ weather_simple_window_popup(GtkWidget *widget, gpointer user_data){
 #else
     window = hildon_window_new();
 #endif
-
     gtk_window_set_title(GTK_WINDOW(window), _("Forecast"));
-    main_vbox = gtk_vbox_new(FALSE, 0);
+
 //    gtk_window_fullscreen (GTK_WINDOW (window));
-    gtk_container_add(GTK_CONTAINER(window), main_vbox);
+/*
+    while(!temp){
+        temp = get_data_from_url("www.bash.org.ru", "temp");
+        if(temp)
+    	    fprintf(stderr, "\nYES \n");
+    	else
+    	    fprintf(stderr, "\nNO \n");
+    }
+*/
+    gtk_container_add(GTK_CONTAINER(window), create_mainbox_for_forecast_window(window, user_data));
     gtk_widget_show(window);
-    gtk_box_pack_start(GTK_BOX(main_vbox), create_top_buttons_box(), FALSE, TRUE, 0);
-    if (app->config->view_mode == COLLAPSED_VIEW_MODE)
-        gtk_box_pack_start(GTK_BOX(main_vbox), view = create_weather_collapsed_view(main_vbox, (gint)user_data), TRUE, TRUE, 0);
-    else
-        gtk_box_pack_start(GTK_BOX(main_vbox), view = create_weather_expanded_view(main_vbox, (gint)user_data), TRUE, TRUE, 0);
 
 #if defined OS2009
     menu = create_view_menu();
@@ -96,18 +122,61 @@ gchar*
 get_next_station_name(const gchar *current_station_name, GtkListStore *user_stations_list){
     GtkTreeIter     iter;
     gboolean        valid,
+                    skipped = FALSE,
+                    first = FALSE,
                     ready = FALSE;
     gchar           *station_name = NULL;
     GtkTreePath     *path;
-//#ifdef DEBUGFUNCTIONCALL
+#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-//#endif
+#endif
     if(!current_station_name)
         return NULL;
 
     path = gtk_tree_path_new_first();
     valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(app->user_stations_list),
                                     &iter, path);
+    while(valid){
+        gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
+                            &iter,
+                            NAME_COLUMN, &station_name,
+                            -1);
+        /* Skip Empty stations */
+        if(ready && !strcmp(station_name, " ")){
+            skipped = TRUE;
+            gtk_tree_path_next(path);
+            valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(app->user_stations_list),
+                                        &iter, path);
+            if(!valid){
+                path = gtk_tree_path_new_first();
+                valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
+                                        &iter);
+                if (first)
+                    break;
+                else
+                    first = TRUE;
+            }
+            continue;
+        }
+        if(ready){
+            break;
+        }
+        else{
+            if(skipped || (app->config->current_station_name) && (station_name) &&
+                  !strcmp(app->config->current_station_name, station_name))
+                ready = TRUE;
+            g_free(station_name);
+            gtk_tree_path_next(path);
+
+            valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(app->user_stations_list),
+                                        &iter, path);
+            if(!valid){
+                valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
+                                        &iter);
+            }
+        }
+    }
+/*
     while(valid){
         gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
                             &iter, NAME_COLUMN, &station_name, -1);
@@ -127,16 +196,43 @@ get_next_station_name(const gchar *current_station_name, GtkListStore *user_stat
                                         &iter);
         }
     }
+*/
     gtk_tree_path_free(path);
+    return station_name;
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
 
     return NULL;
+}
+/*******************************************************************************/
+void
+weather_simple_window_redraw(GtkWidget *window){
+    GtkWidget* main_vbox;
+    gpointer user_data;
+
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+
+    main_vbox = (GtkWidget*)g_object_get_data(G_OBJECT(window), "main_vbox");
+    user_data = g_object_get_data(G_OBJECT(window), "user_data");
+    if (main_vbox)
+        gtk_widget_destroy(main_vbox);
+    main_vbox =  create_mainbox_for_forecast_window(window, user_data);
+    gtk_container_add(GTK_CONTAINER(window), main_vbox);
+    gtk_widget_show(main_vbox);
+    gtk_widget_show(window);
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
 }
 /*******************************************************************************/
 GtkWidget*
-create_top_buttons_box(void){
+create_top_buttons_box(GtkWidget* window, gpointer user_data){
     GtkWidget       *buttons_box = NULL,
                     *station_button = NULL,
                     *update_button = NULL;
@@ -158,7 +254,7 @@ create_top_buttons_box(void){
     station_button = create_button_with_2_line_text(app->config->current_station_name,
                                                     buffer, 18, 12);
     g_signal_connect(G_OBJECT(station_button), "button-release-event",
-                            G_CALLBACK(change_station_next), GINT_TO_POINTER(1));
+                            G_CALLBACK(change_station_next), window);
     gtk_widget_set_size_request(station_button, -1, 80);
     /* prepare last update time*/
     if(app->station_data){
@@ -186,6 +282,11 @@ create_top_buttons_box(void){
 
     gtk_box_pack_start(GTK_BOX(buttons_box), station_button, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(buttons_box), update_button, TRUE, TRUE, 0);
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+    gtk_widget_show(buttons_box);
     return buttons_box;
 }
 /*******************************************************************************/
@@ -220,7 +321,6 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
 #if defined OS2009
     scrolled_window = hildon_pannable_area_new ();
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA (scrolled_window), GTK_WIDGET (main_vbox));
-
 #else
     /* scrolled window */
     scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -232,19 +332,22 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
     vscrollbar = gtk_scrolled_window_get_vscrollbar(scrolled_window);
     hildon_helper_set_thumb_scrollbar (scrolled_window, TRUE);
     /* pack childs to the scrolled window */
-#endif
     gtk_scrolled_window_add_with_viewport(scrolled_window, main_vbox);
+#endif
 
     days = (GSList*)g_hash_table_lookup(app->station_data, "forecast");
     if(days){
         while(days){
             day = (GHashTable*)(days->data);
-            line = gtk_event_box_new();
-            g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
-            g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
-            g_signal_connect(G_OBJECT(line), "button-release-event",
+            line = gtk_button_new();
+            gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
+            gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
+            g_signal_connect(G_OBJECT(line), "clicked",
                                 G_CALLBACK(show_expanded_day_button_handler),
                                  GINT_TO_POINTER(i));
+            g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
+            g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
+
             /* line box */
             line_hbox = gtk_hbox_new(FALSE, 0);
             gtk_container_add(GTK_CONTAINER(line), line_hbox);
@@ -365,6 +468,10 @@ create_weather_collapsed_view(GtkWidget *vbox, gint day_number){
         set_font(label, NULL, 24);
     }
     gtk_widget_show_all(scrolled_window);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
     return scrolled_window;
 }
 /*******************************************************************************/
@@ -428,12 +535,14 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
         if( (current_data_last_update >
                 ( current_time - app->config->data_valid_interval)) &&
                 (current_data_last_update < ( current_time + app->config->data_valid_interval))){
-            line = gtk_event_box_new();
-            g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
-            g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
-            g_signal_connect(G_OBJECT(line), "button-release-event",
+            line = gtk_button_new();
+            gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
+            gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
+            g_signal_connect(G_OBJECT(line), "clicked",
                                 G_CALLBACK(show_detailes_of_current_day_button_handler),
                                  GINT_TO_POINTER(i));
+            g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
+            g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
             current_widget = create_current_tab(current);
             if(current){
                 gtk_container_add(GTK_CONTAINER(line), current_widget);
@@ -447,18 +556,23 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
     tmp = g_hash_table_lookup(app->station_data, "forecast");
     while(tmp && i < Max_count_weather_day){
         day = (GHashTable*)tmp->data;
-        line = gtk_event_box_new();
+            line = gtk_button_new();
+            gtk_button_set_focus_on_click(GTK_BUTTON(line), FALSE);
+            gtk_button_set_relief(GTK_BUTTON(line), GTK_RELIEF_NONE);
+            g_signal_connect(G_OBJECT(line), "clicked",
+                                G_CALLBACK(show_collapsed_day_button_handler),
+                                 GINT_TO_POINTER(i));
+
         g_object_set_data(G_OBJECT(line), "scrolled_window", (gpointer)scrolled_window);
         g_object_set_data(G_OBJECT(line), "vbox", (gpointer)vbox);
-        g_signal_connect(G_OBJECT(line), "button-release-event",
-                                G_CALLBACK(show_collapsed_day_button_handler),
-                               GINT_TO_POINTER(i));
+
         day_widget = create_day_tab(current, day, &day_name);
         gtk_container_add(GTK_CONTAINER(line), day_widget);
         gtk_box_pack_start(GTK_BOX(main_vbox), line, TRUE, TRUE, 0);
         gtk_box_pack_start(GTK_BOX(main_vbox), separator = gtk_hseparator_new(), FALSE, TRUE, 0);
 
-        if(day_number == i){
+        /* If activited day and not current weather */
+        if(day_number == i && !(i == 0 && current_widget && current)){
             fprintf(stderr,"This day must be activity!!! %i\n",i);
             g_object_set_data(G_OBJECT(scrolled_window), "selected_widget", (gpointer)separator);
         }
@@ -474,8 +588,7 @@ create_weather_expanded_view(GtkWidget *vbox, gint day_number){
 }
 /*******************************************************************************/
 void
-show_collapsed_day_button_handler(GtkWidget *button, GdkEventButton *event,
-                                                            gpointer user_data){
+show_collapsed_day_button_handler(GtkWidget *button, gpointer user_data){
     GtkWidget *view;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -487,8 +600,7 @@ show_collapsed_day_button_handler(GtkWidget *button, GdkEventButton *event,
 }
 /*******************************************************************************/
 void
-show_expanded_day_button_handler(GtkWidget *button, GdkEventButton *event,
-                                                            gpointer user_data){
+show_expanded_day_button_handler(GtkWidget *button, gpointer user_data){
     GtkWidget *view;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -500,8 +612,7 @@ show_expanded_day_button_handler(GtkWidget *button, GdkEventButton *event,
 }
 /*******************************************************************************/
 void
-show_detailes_of_current_day_button_handler(GtkWidget *button, GdkEventButton *event,
-                                                            gpointer user_data){
+show_detailes_of_current_day_button_handler(GtkWidget *button, gpointer user_data){
     GtkWidget *view;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -528,7 +639,7 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
     const gchar     *wind_units_str[] = {"m/s", "km/h", "mi/h" };
     gchar           buffer[1024],
                     tmp[512],
-                    buff[512],
+                    buff[1024],
                     hour_last_update[1024];
     GHashTable      *hour_weather = NULL;
     GSList          *hours_weather = NULL;
@@ -585,10 +696,10 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
             timezone = atol(g_hash_table_lookup(g_hash_table_lookup(app->station_data, 
                                     "location"), "station_time_zone"));
             current_time = utc_time + 60 * 60 *timezone;
-            fprintf(stderr, "\nTIME %d\n", current_time);
+//            fprintf(stderr, "\nTIME %d\n", current_time);
 
             *hour_last_update = 0;
-            *buff = 0;
+            memset(buff, 0, sizeof(buff));
 
             /*Prepare date from xml file*/
 
@@ -597,7 +708,7 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
                                                "detail"), "last_update"));
             date_size = strcspn(hour_last_update, " ");
             strncpy(buff, hour_last_update, date_size);
-            strcat(buff, "");
+//            fprintf(stderr, "\nbuff %s\n", buff);
 
             *hour_last_update = 0;
             strcat(hour_last_update, buff);
@@ -606,14 +717,14 @@ create_weather_for_two_hours_collapsed_view(GtkWidget *vbox, gint day_number){
             strcat(hour_last_update, ":00:00");
 
             strptime(hour_last_update, "%D %T", &tmp_tm);
-            fprintf(stderr, "\nhour_last_update %s\n", hour_last_update);
+//            fprintf(stderr, "\nhour_last_update %s\n", hour_last_update);
             hours_time = mktime(&tmp_tm);
             if((count > 1) && 
                         (!strcmp((char*)g_hash_table_lookup(hour_weather, "hours"), "00")))
                 new_day = TRUE;
             if(new_day)
                 hours_time += 24*60*60;
-            fprintf(stderr, "\nhours_time %d\n", hours_time);
+//            fprintf(stderr, "\nhours_time %d\n", hours_time);
             difference = difftime(hours_time, current_time);
 
             if((difference < 0 && difference > -60*60) || difference >= 0 ||
