@@ -415,13 +415,23 @@ save_station(GtkWidget *window){
     /* Update config file */
     config_save(app->config);
     stations_box = (gpointer)(g_object_get_data(G_OBJECT(window), "station_box"));
-    gtk_widget_destroy(stations_box);
+    if (stations_box)
+        gtk_widget_destroy(stations_box);
     stations_box = create_and_fill_stations_buttons((GtkWidget*)(g_object_get_data(G_OBJECT(window), "settings_window_table")));
     gtk_widget_show (stations_box);
     gtk_table_attach((GtkTable*)(g_object_get_data(G_OBJECT(window), "settings_window_table")),
                                 stations_box, 1, 2, 1, 2, (GtkAttachOptions)0,
                                 (GtkAttachOptions)0, 0, 0 );
 
+    /* Run gps daemon */
+    if (is_gps && g_strdup(g_object_get_data(G_OBJECT(window), "station_code")) &&
+       !strcmp(g_strdup(g_object_get_data(G_OBJECT(window), "station_code"))," ")){
+       fprintf(stderr, "GPS!!!!!!!!!!!!!!1\n");
+       if (app->gps_control){
+          location_gpsd_control_start(app->gps_control);
+          app->gps_was_started = TRUE;
+       }
+    }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -1501,6 +1511,7 @@ create_station_button(gint station_number, gchar* station_name_s, gchar *station
 
     snprintf(buffer, sizeof(buffer) - 1, "Station %i", station_number + 1);
     button = create_button_with_2_line_text(buffer, station_name_s, 18, 12);
+    g_object_set_data(G_OBJECT(button), "station_number", (gpointer)station_number);
     g_object_set_data(G_OBJECT(button), "station_name", (gpointer)station_name_s);
     g_object_set_data(G_OBJECT(button), "station_code", (gpointer)station_code_s);
     g_object_set_data(G_OBJECT(button), "station_source", (gpointer)station_source_s);
@@ -1508,13 +1519,11 @@ create_station_button(gint station_number, gchar* station_name_s, gchar *station
     g_object_set_data(G_OBJECT(button), "station_region", (gpointer)station_region_s);
     g_object_set_data(G_OBJECT(button), "station_country_id", (gpointer)country_id);
     g_object_set_data(G_OBJECT(button), "station_region_id", (gpointer)region_id);
-    g_object_set_data(G_OBJECT(button), "station_number", (gpointer)station_number);
     if (is_gps)
         g_object_set_data(G_OBJECT(button), "station_is_gps", (gpointer)1);
     else
         g_object_set_data(G_OBJECT(button), "station_is_gps", (gpointer)0);
 
-
     g_signal_connect(G_OBJECT(button), "button-release-event",
                      G_CALLBACK(station_setup_button_handler),
                      (gpointer)button);
@@ -1552,6 +1561,11 @@ create_and_fill_stations_buttons(GtkWidget *main_table){
         gtk_tree_model_get_iter_first(GTK_TREE_MODEL
                                       (app->user_stations_list), &iter);
     while(valid){
+        station_name = NULL;
+        station_code = NULL;
+        station_source = NULL;
+        station_country = NULL;
+        station_region = NULL;
         gtk_tree_model_get(GTK_TREE_MODEL(app->user_stations_list),
                            &iter,
                            0, &station_name,
